all.ChiValsm<-function(){
     cat("\n")
     note_for_ChiValsm_input()
     cat("\n")
     note_for_close_window()
     ChiValSMMpar<-data.frame(parameter=c("TBW (Kg)","CBZ","D (mg)","tau (hr)"),value=c(0))
     ChiValSMMpar<-edit(ChiValSMMpar)
##     ChiValSMMpar<-zcheck(ChiValSMMpar)
     cat("\n")
     note_for_ChiValsm_conc_input()
     cat("\n")
     note_for_close_window()
     ChiValSMpar<-data.frame(ts=c(0),conc=c(0))
     ChiValSMpar<-edit(ChiValSMpar)
     ChiValSMpar<-mscheck(ChiValSMpar)
     cat("\n")
     ChiVal.sm(length(ChiValSMpar$ts),ChiValSMpar$conc,ChiValSMpar$ts,ChiValSMMpar[4,2],ChiValSMMpar[3,2],ChiValSMMpar[1,2],ChiValSMMpar[2,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_ChiValsm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-ChiValcpr(ChiValSMMpar[3,2],ChiValSMMpar[4,2],ChiValSMMpar[4,2],ChiValSMMpar[1,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)    
     cat("\n") 
     ChiVal.more(ChiValSMMpar[1,2])
}